@@ -14,6 +14,7 @@ from click_aliases import ClickAliasedGroup
 from .c import Qt5Templates, c as _c, qt5 as _qt5
 from .common import create_common_files
 from .golang import GoCombinations, golang as _golang
+from .kotlin import kotlin as _kotlin
 from .notes import notes as _notes
 from .python import python as _python
 
@@ -41,7 +42,10 @@ def clean():
 
     for root, dirs, files in os.walk("."):
         for f in files:
-            if f.lower().find("example") != -1 or f in {"ToolkitPy_logo.png"}:
+            if f.lower().find("example") != -1 or f in {
+                "ToolkitPy_logo.png",
+                "entity_template.go",
+            }:
                 f = os.path.join(root, f)
                 click.echo(f"clean {f}")
                 os.unlink(f)
@@ -126,3 +130,8 @@ def c(only_files):
 )
 def qt5(template=Qt5Templates.Gui, only_files=""):
     _qt5(template, only_files)
+
+
+@command_cps.command(help="Create kotlin project scaffold.")
+def kotlin():
+    _kotlin()
